@@ -319,6 +319,13 @@ test_that("scatterPlot labeling with numbers", {
             labels.use.numbers = TRUE,
             labels.numbers.spacer = "_"),
         "ggplot")
+    # Robust to legend title removal
+    expect_s3_class(
+        scatterPlot(
+            df, "PC1", "PC2", disc, do.label = TRUE,
+            labels.use.numbers = TRUE,
+            legend.color.title = NULL),
+        "ggplot")
     # Colors should match with this original
     expect_s3_class(
         scatterPlot(
@@ -404,6 +411,15 @@ test_that("scatterPlot lettering works", {
         "ggplot")
 })
 
+test_that("scatterPlot lettering request warns when conflicts with shape.by", {
+    ### Manual Check: No lettering, shaping instead
+    expect_warning(
+        scatterPlot(
+            df, "PC1", "PC2", disc,
+            do.letter = TRUE, shape.by = disc2, size = 3),
+        "'do.letter' ignored due to")
+})
+
 test_that("scatterPlot plotting order can be ordered by the data, or have order randomized", {
     un <- scatterPlot(df, "PC1", "PC2", disc, data.out = TRUE, size = 10, plot.order = "unordered")
     dec <- scatterPlot(df, "PC1", "PC2", disc, data.out = TRUE, size = 10, plot.order = "decreasing")
